@@ -3,8 +3,9 @@ import click
 from .._version import __version__
 from .bscan import bscan
 from .gff import gff_dedup
+from .hscan import hscan
 from .press import press
-from .scan import scan
+from .pscan import pscan
 from .score import score
 from .strip import strip
 
@@ -19,7 +20,8 @@ def cli():
 
 cli.add_command(bscan)
 cli.add_command(gff_dedup)
+cli.add_command(hscan)
 cli.add_command(press)
-cli.add_command(scan)
+cli.add_command(pscan)
 cli.add_command(score)
 cli.add_command(strip)
